void RunFmsCluster(int nevents = 3e3, const char* file = "9065073.list")
{
  // Load shared libraries
  gROOT->Macro("loadMuDst.C");
  gROOT->Macro("LoadLogger.C");

  // Load your shared libraries here
  gSystem->Load("StFmsAnalysisMaker");

  // Create chain
  StChain* chain = new StChain;

  // Instantiate MuDst maker
  StMuDstMaker* muDstMaker = new StMuDstMaker(0,0,"",file,".",1000,"MuDst");
  StMuDbReader* muDB = StMuDbReader::instance();

  // Instantiate your makers here
  StFmsAnalysisMaker* fms = new StFmsAnalysisMaker;
  fms->SetPrintLevel(0);
  fms->SetFile("fms.root");
  TCanvas* c1=new TCanvas("c1","c1",600,600);
  c1->Divide(2,1);
  c1->GetPad(2)->SetLogy();
  TCanvas* c2=new TCanvas("c2","c2",600,600);
  c2->Divide(2,2);
  c2->Update();
  printf("c2 update\n");
  c1->cd();
  // Initialize chain
  chain->Init();
  { 
    FitTower::Setwe_ab(0.65,.51,-.16,.8,.2,7.6);
  };
  TH2F* FmsH[4];
  TH1F* SummedEnergy=new TH1F("SummedEnergy","SummedFMSEnergy",120,0,120);
  SummedEnergy->GetXaxis()->SetTitle("Energy in 4 FMS detectors (GeV)");

  // Event loop
  cout<<"Prepare to process "<<nevents<<" events.\n";
  for (int iEvent = 1; iEvent <= nevents; ++iEvent) 
    {
      if(iEvent%100==1)cout<<"iEvent="<<iEvent<<"\n";
      chain->Clear();
      int status = chain->Make(iEvent);
      fms->SetPrintLevel(0);
      if (status % 10 == kStEOF || status % 10 == kStFatal) break;
      /*
      TH2F NorthLarge(*(fms->GetEnergy(0)));
      NorthLarge.SetName("NorthLargeFMS");
      c1->cd(1);
      NorthLarge.Draw("zcol");
      TH2F SouthLarge(*(fms->GetEnergy(1)));
      SouthLarge.SetName("SouthLargeFMS");
      c1->cd(2);
      SouthLarge.Draw("zcol");
      TH2F NorthSmall(*(fms->GetEnergy(2)));
      NorthSmall.SetName("NorthSmallFMS");
      c1->cd(3);
      NorthSmall.Draw("zcol");
      TH2F SouthSmall(*(fms->GetEnergy(3)));
      SouthSmall.SetName("SouthSmallFMS");
      c1->cd(4);
      SouthSmall.Draw("zcol");
      c1->Update();
      */
      HitCluster* hcl=0;
      Float_t eventEnergy=0;
      SummedEnergy->Fill(eventEnergy);

      if(iEvent%1000==1)
	{
	  c1->cd(1);
	  TH2F* hmass=fms->get_MvsE();
	  hmass->GetXaxis()->SetTitle("2 Photon Mass (GeV)");
	  hmass->ProjectionX("EnergyGT10",11,100)->Draw();
	  c1->cd(2);
	  SummedEnergy->Draw();
	  cout<<"Update****\n";
	  c1->Update();

	}; 
    }

  for(int jj=0;jj<4;jj++)
    {
      c2->cd(jj+1);
      c2->GetPad(jj+1)->SetLogz();
      fms->GetQt()->qtHist[jj]->Draw("box");

    };
  c2->Update();
}
