void RunFmsSeePi0(int nevents = 5e3, const char* file = "9065073.list")
{
  // Load shared libraries
  gROOT->Macro("loadMuDst.C");
  gROOT->Macro("LoadLogger.C");

  // Load your shared libraries here
  gSystem->Load("StFmsAnalysisMaker");

  // Create chain
  StChain* chain = new StChain;

  // Instantiate MuDst maker
  StMuDstMaker* muDstMaker = new StMuDstMaker(0,0,"",file,".",1000,"MuDst");
  StMuDbReader* muDB = StMuDbReader::instance();

  // Instantiate your makers here
  StFmsAnalysisMaker* fms = new StFmsAnalysisMaker;
  fms->SetPrintLevel(0);
  fms->SetFile("fms.root");
  TCanvas* c1=new TCanvas("c1","c1",600,600);
  c1->Divide(2,1);
  c1->GetPad(2)->SetLogy();

  // Initialize chain
  chain->Init();

  TH2F* FmsH[4];
  TH1F* SummedEnergy=new TH1F("SummedEnergy","SummedFMSEnergy",120,0,120);
  SummedEnergy->GetXaxis()->SetTitle("Energy in 4 FMS detectors (GeV)");

  // Event loop
  cout<<"Prepare to process "<<nevents<<" events.\n";
  for (int iEvent = 1; iEvent <= nevents; ++iEvent) 
    {
      if(iEvent%100==1)cout<<"iEvent="<<iEvent<<"\n";
      chain->Clear();
      int status = chain->Make(iEvent);
      fms->SetPrintLevel(0);
      if (status % 10 == kStEOF || status % 10 == kStFatal) break;

      Float_t eventEnergy=0;
      for(Int_t nstb=0;nstb<4;nstb++)eventEnergy+=fms->GetEnergy(nstb)->Sum();
      SummedEnergy->Fill(eventEnergy);

      if(iEvent%1000==1)
	{
	  c1->cd(1);
	  TH2F* hmass=fms->get_MvsE();
	  hmass->GetXaxis()->SetTitle("2 Photon Mass (GeV)");
	  hmass->ProjectionX("EnergyGT10",20,100)->Draw();
	  c1->cd(2);
	  SummedEnergy->Draw();
	  cout<<"Update****\n";
	  c1->Update();
	}; 
    }
}
